Enum jsonptr::Error

source ·
pub enum Error {
    Index(IndexError),
    Unresolvable(UnresolvableError),
    NotFound(NotFoundError),
}
An enum representing possible errors that can occur when resolving or mutating by a JSON Pointer.

Variants



Index(IndexError)

Indicates an error occurred while parsing a usize (ParseError) or the parsed value was out of bounds for the targeted array.



Unresolvable(UnresolvableError)

Represents an error that occurs when attempting to resolve a Pointer that encounters a leaf node (i.e. a scalar / null value) which is not the root of the Pointer.



NotFound(NotFoundError)

Indicates that a Pointer was not found in the data.

Implementations

source

impl Error

source

pub fn is_index(&self) -> bool

Returns true if the error is Error::IndexError.

source

pub fn is_unresolvable(&self) -> bool

Returns true if the error is Error::UnresolvableError.

source

pub fn is_not_found(&self) -> bool

Returns true if the error is Error::NotFoundError.