Enum jsonptr::MalformedPointerError
source · [−]Expand description
Indicates that a Pointer was malformed.
Variants
NoLeadingSlash(String)
Indicates that the Pointer was malformed because it did not contain a
leading slash ('/').
InvalidEncoding(String)
Indicates that the Pointer was malformed because it contained invalid encoding.