Module jsonptr::prelude

source ·
Exposes the traits Assign, Delete, Resolve, ResolveMut

Traits

  • Assign is implemented by types which can internally assign a serde_json::Value by a JSON Pointer.
  • Delete is implemented by types which can internally remove a value based on a JSON Pointer
  • Resolve is implemented by types which can resolve a reference to a serde_json::Value from the path in a JSON Pointer.
  • ResolveMut is implemented by types which can resolve a mutable reference to a serde_json::Value from the path in a JSON Pointer.