Struct jsonptr::ParseError
source · [−]pub struct ParseError<T> {
pub source: T,
pub token: Token,
}Fields
source: Ttoken: TokenTrait Implementations
sourceimpl<E> Debug for ParseError<E> where
E: StdError + 'static,
impl<E> Debug for ParseError<E> where
E: StdError + 'static,
sourceimpl<E> Display for ParseError<E> where
E: StdError,
impl<E> Display for ParseError<E> where
E: StdError,
sourceimpl<E> Error for ParseError<E> where
E: StdError + 'static + Send + Sync,
impl<E> Error for ParseError<E> where
E: StdError + 'static + Send + Sync,
sourcefn source(&self) -> Option<&(dyn StdError + 'static)>
fn source(&self) -> Option<&(dyn StdError + 'static)>
The lower-level source of this error, if any. Read more
sourcefn backtrace(&self) -> Option<&Backtrace>
fn backtrace(&self) -> Option<&Backtrace>
🔬 This is a nightly-only experimental API. (
backtrace)Returns a stack backtrace, if available, of where this error occurred. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎 Deprecated since 1.42.0:
use the Display impl or to_string()
sourceimpl<T: PartialEq> PartialEq<ParseError<T>> for ParseError<T>
impl<T: PartialEq> PartialEq<ParseError<T>> for ParseError<T>
sourcefn eq(&self, other: &ParseError<T>) -> bool
fn eq(&self, other: &ParseError<T>) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ParseError<T>) -> bool
fn ne(&self, other: &ParseError<T>) -> bool
This method tests for !=.
impl<T: Eq> Eq for ParseError<T>
impl<T> StructuralEq for ParseError<T>
impl<T> StructuralPartialEq for ParseError<T>