pub enum Error {
Index(IndexError),
Unresolvable(UnresolvableError),
NotFound(NotFoundError),
MalformedPointer(MalformedPointerError),
}Expand description
An enum representing possible errors that can occur when resolving or mutating by a JSON Pointer.
Variants
Index(IndexError)
Indicates an error occurred while parsing a usize (ParseError) or the
parsed value was out of bounds for the targeted array.
Unresolvable(UnresolvableError)
Represents an error that occurs when attempting to resolve a Pointer that
encounters a leaf node (i.e. a scalar / null value) which is not the root
of the Pointer.
NotFound(NotFoundError)
Indicates that a Pointer was not found in the data.
MalformedPointer(MalformedPointerError)
Indicates that a Pointer was malformed.
Implementations
sourceimpl Error
impl Error
sourcepub fn is_unresolvable(&self) -> bool
pub fn is_unresolvable(&self) -> bool
Returns true if the error is Error::UnresolvableError.
sourcepub fn is_not_found(&self) -> bool
pub fn is_not_found(&self) -> bool
Returns true if the error is Error::NotFoundError.
sourcepub fn is_malformed_pointer(&self) -> bool
pub fn is_malformed_pointer(&self) -> bool
Returns true if the error is Error::MalformedPointerError.